@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2009, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2011, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/inmethod.c,v 1.7 2009/10/02 15:31:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/inmethod.c,v 1.13 2011/05/16 16:21:58 william Exp $
  */
 
 #define _INCLUDE_FROM_INMETHOD_C_
@@ -652,7 +652,7 @@ static struct tagIMInfo gstIMInfo[] = {
    },
 #endif /* ~_NO_XIM */
 #ifndef _NO_TGTWB5
-   { "tgtwb5", TGIM_TGTWB5, TGIM_DBIM,
+   { "tgtwb5/tgchgb", TGIM_TGTWB5, TGIM_DBIM,
      Tgtwb5CleanUp, Tgtwb5Init, NULL, NULL,
      Tgtwb5SendKey, NULL, Tgtwb5ExpectCM, NULL,
      Tgtwb5ActiveOnCntrlSpace, Tgtwb5HandleCntrlSpace,
@@ -747,6 +747,14 @@ int InitInputMethods()
          psz = XGetDefault(mainDisplay, TOOL_NAME, "SingleByteInputMethod");
          single_double = TGIM_SBIM;
       } else {
+         if (XGetDefault(mainDisplay, TOOL_NAME, "SingleByteInputMethod") !=
+               NULL) {
+            sprintf(gszMsgBox, TgLoadString(STID_TWO_XDEF_ONE_IGNORED),
+                  TOOL_NAME, "DoubleByteInputMethod", TOOL_NAME,
+                  "SingleByteInputMethod", TOOL_NAME, "SingleByteInputMethod");
+            Msg(gszMsgBox);
+            fprintf(stderr, "%s\n", gszMsgBox);
+         }
          single_double = TGIM_DBIM;
       }
    }
@@ -759,25 +767,70 @@ int InitInputMethods()
 
       if (psz_comma != NULL) *psz_comma = '\0';
       for ( ; pIMInfo->pszName != NULL; pIMInfo++, i++) {
-         if (UtilStrICmp(psz, pIMInfo->pszName) == 0 &&
-               (single_double & pIMInfo->nSingleDouble) == single_double) {
-            gnInputMethod = pIMInfo->nInputMethod;
-            gnInputMethodIndex = i;
-            gpIMInfo = pIMInfo;
-            if (gstIMInfo[gnInputMethodIndex].pInitFunc != NULL) {
-               if (psz_comma == NULL) {
-                  if (!((gstIMInfo[gnInputMethodIndex].pInitFunc)(mainDisplay,
-                        mainWindow, NULL))) {
-                     /* may not be a problem */
-                  }
-               } else {
-                  if (!((gstIMInfo[gnInputMethodIndex].pInitFunc)(mainDisplay,
-                        mainWindow, &psz_comma[1]))) {
-                     /* may not be a problem */
+         char *psz_slash=strchr(pIMInfo->pszName,'/');
+
+         if (psz_slash == NULL) {
+            if (UtilStrICmp(psz, pIMInfo->pszName) == 0 &&
+                  (single_double & pIMInfo->nSingleDouble) == single_double) {
+               gnInputMethod = pIMInfo->nInputMethod;
+               gnInputMethodIndex = i;
+               gpIMInfo = pIMInfo;
+               if (gstIMInfo[gnInputMethodIndex].pInitFunc != NULL) {
+                  if (psz_comma == NULL) {
+                     if (!((gstIMInfo[gnInputMethodIndex].pInitFunc)(mainDisplay,
+                           mainWindow, NULL))) {
+                        /* may not be a problem */
+                     }
+                  } else {
+                     if (!((gstIMInfo[gnInputMethodIndex].pInitFunc)(mainDisplay,
+                           mainWindow, &psz_comma[1]))) {
+                        /* may not be a problem */
+                     }
                   }
                }
+               break;
+            }
+         } else {
+            char *psz_dup=UtilStrDup(pIMInfo->pszName), *psz_cur=NULL;
+            int done=FALSE;
+
+            if (psz_dup == NULL) FailAllocMessage();
+            psz_cur = psz_dup;
+            psz_slash = strchr(psz_cur, '/');
+            while (!done) {
+               if (psz_slash != NULL) *psz_slash = '\0';
+               if (UtilStrICmp(psz, psz_cur) == 0 &&
+                     (single_double & pIMInfo->nSingleDouble) == single_double) {
+                  gnInputMethod = pIMInfo->nInputMethod;
+                  gnInputMethodIndex = i;
+                  gpIMInfo = pIMInfo;
+                  if (gstIMInfo[gnInputMethodIndex].pInitFunc != NULL) {
+                     if (psz_comma == NULL) {
+                        if (!((gstIMInfo[gnInputMethodIndex].pInitFunc)(mainDisplay,
+                              mainWindow, NULL))) {
+                           /* may not be a problem */
+                        }
+                     } else {
+                        if (!((gstIMInfo[gnInputMethodIndex].pInitFunc)(mainDisplay,
+                              mainWindow, &psz_comma[1]))) {
+                           /* may not be a problem */
+                        }
+                     }
+                  }
+                  done = TRUE;
+               }
+               if (psz_slash != NULL) {
+                  *psz_slash++ = '/';
+                  psz_cur = psz_slash;
+                  psz_slash = strchr(psz_cur, '/');
+               } else {
+                  break;
+               }
+            }
+            UtilFree(psz_dup);
+            if (done) {
+               break;
             }
-            break;
          }
       }
       if (psz_comma != NULL) *psz_comma++ = ',';
