@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2009, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2011, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/menuinfo.c,v 1.50 2009/10/22 03:44:01 cvsps Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/menuinfo.c,v 1.59 2011/05/19 21:31:41 william Exp $
  */
 
 #define _INCLUDE_FROM_MENUINFO_C_
@@ -45,6 +45,7 @@
 #include "font.e"
 #include "grid.e"
 #include "help.e"
+#include "imgproc.e"
 #include "import.e"
 #include "menu.e"
 #include "menuinfo.e"
@@ -424,6 +425,27 @@ static TgMenuItemInfo generateMenuItemInfo[] = {
 static TgMenuInfo generateMenuInfo={ TGMUTYPE_TEXT, generateMenuItemInfo,
                                      TgCreateMenuFromMenuInfo };
 
+static TgMenuItemInfo fillReplaceMenuItemInfo[] = {
+   { N_("Replace Color"), NULL,
+     N_("Replace a color in a selected image with the current color"), NULL,
+     CMDID_REPLACECOLOR },
+   { N_("Replace Color with Transparent"), NULL,
+     N_("Replace a color in a selected image with a transparent color"), NULL,
+     CMDID_REPLACECOLORWITHTRANS },
+   { N_("Flood Fill"), NULL,
+     N_("Flood-fill a selected image with the current color"),
+     NULL, CMDID_FLOODFILL },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Enable Threshold-based Flood and Replace Color"), NULL,
+     N_("Enable flood fill and replace color to apply to colors similar to the selected pixel (+/- a threshold)"),
+     NULL, CMDID_TOGGLEFLOODREPLACECOLORTHRESH },
+   { N_("Set Flood and Replace Color Threshold"), NULL,
+     N_("Set flood fill and replace color threshold"),
+     NULL, CMDID_SETFLOODREPLACECOLORTHRESH },
+   { NULL, NULL, NULL, NULL, INVALID }
+};
+static TgMenuInfo fillReplaceMenuInfo={ TGMUTYPE_TEXT, fillReplaceMenuItemInfo,
+                                        CreateImageProcMenu };
 static TgMenuItemInfo imageProcMenuItemInfo[] = {
    { N_("Make Gray"), NULL, N_("Convert a selected image into gray-scale"),
      NULL, CMDID_MAKEGRAY },
@@ -456,6 +478,8 @@ static TgMenuItemInfo imageProcMenuItemInfo[] = {
      N_("Effects submenu >>>"), &effectsMenuInfo, INVALID },
    { N_("Generate"), TGMUITEM_SUBMENU,
      N_("Generate submenu >>>"), &generateMenuInfo, INVALID },
+   { N_("Flood Fill / Replace Colors"), TGMUITEM_SUBMENU,
+     N_("Flood fill and replace colors submenu >>>"), &fillReplaceMenuInfo, INVALID },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Regenerate Image"), NULL,
      N_("Regenerated a selected image"), NULL, CMDID_REGENERATEIMAGE },
@@ -464,12 +488,6 @@ static TgMenuItemInfo imageProcMenuItemInfo[] = {
    { N_("Get Color"), NULL,
      N_("Pick a color from a selected image to be the current color"), NULL,
      CMDID_GETCOLOR },
-   { N_("Replace Color"), NULL,
-     N_("Replace a color in a selected image with the current color"), NULL,
-     CMDID_REPLACECOLOR },
-   { N_("Flood Fill"), NULL,
-     N_("Flood-filling a selected image with the current color"),
-     NULL, CMDID_FLOODFILL },
    { N_("Create Contour"), NULL,
      N_("Generate a contour from a point in a selected image"), NULL,
      CMDID_CREATECONTOUR },
@@ -757,13 +775,16 @@ static TgMenuItemInfo bitPixmapMenuItemInfo[] = {
      N_("Break selected bitmap/pixmap object into smaller objects"), NULL,
      CMDID_BREAKUPBITPIXMAP },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Remove Transparent Pixel For Pixmap..."), NULL,
+     N_("Remove transparent pixels for selected pixmap objects"), NULL,
+     CMDID_REMOVETRANSPIXEL },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Export Half Tone Bitmap"), NULL,
      N_("Use Floyd-Steinberg half-tone method when exporting an X11 bitmap file"),
      NULL, CMDID_EXPORTHALFTONEBITMAP },
    { N_("Export Threshold Bitmap"), NULL,
      N_("Use simple thresholding method when exporting an X11 bitmap file"),
      NULL, CMDID_EXPORTTHRESHOLDBITMAP },
-   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Set Export Bitmap Threshold..."), NULL,
      N_("Set bitmap threshold value for the simple thresholding method"),
      NULL, CMDID_SETEXPORTBITMAPTHRESHOLD },
@@ -947,8 +968,7 @@ static TgMenuItemInfo editMenuItemInfo[] = {
    { N_("Redraw"), "Cntrl+r", N_("Redraw canvas window"), NULL, CMDID_REDRAW },
    { N_("Duplicate"), "Cntrl+d", N_("Duplicate selected objects"), NULL,
      CMDID_DUPLICATE },
-   { N_("Delete"), "Cntrl+x", N_("Delete selected objects"), NULL,
-     CMDID_DELETE },
+   { N_("Delete"), NULL, N_("Delete selected objects"), NULL, CMDID_DELETE },
    { N_("Select All"), "Cntrl+a", N_("Select all objects on the current page"),
      NULL, CMDID_SELECTALL },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
@@ -962,7 +982,7 @@ static TgMenuItemInfo editMenuItemInfo[] = {
    { N_("Copy"), "Cntrl+c", N_("Copy selected objects into the cut buffer"),
      NULL, CMDID_COPY },
    { N_("Copy Plain Text As Object"), NULL,
-     N_("Copy highlighted plain text as an object into the cut buffer"), NULL,
+     N_("Copy highlighted plain text as an object into the cut buffer (to be pasted into Tgif)"), NULL,
      CMDID_COPYPLAINTEXTASOBJECT },
    { N_("Cut"), NULL, N_("Cut selected objects into the cut buffer"), NULL,
      CMDID_CUT },
