@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2009, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2011, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/page.c,v 1.13 2009/11/08 00:32:44 cvsps Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/page.c,v 1.15 2011/05/16 16:21:58 william Exp $
  */
 
 #define _INCLUDE_FROM_PAGE_C_
@@ -1337,7 +1337,7 @@ int GetDimensionInDouble(Spec, nNonPosReturnOK, pd_num_pixels)
    double *pd_num_pixels;
 {
    char *c_ptr=NULL;
-   double dval;
+   double dval=(double)0;
 
    /* do not translate -- program constants */
    if ((c_ptr=strstr(Spec, "in")) != NULL ||
