@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2006, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2009, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shortcut.c,v 1.13 2006/06/12 23:59:07 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shortcut.c,v 1.46 2011/05/16 16:21:59 william Exp $
  */
 
 #define _INCLUDE_FROM_SHORTCUT_C_
@@ -41,7 +41,7 @@ static struct ShortCutRec shortCutXlateTbl[] = {
 /* Control Keys */
    { 'a', CNTRL_ONLY, "SelectAll()", 0, CMDID_SELECTALL },
    { 'b', CNTRL_ONLY, "Back()", 0, CMDID_BACK },
-   { 'c', CNTRL_ONLY, "Copy()", 0, CMDID_COPY },
+   { 'c', CNTRL_ONLY, "CopyToCutBuffer()", 0, CMDID_COPY },
    { 'd', CNTRL_ONLY, "Duplicate()", 0, CMDID_DUPLICATE },
    { 'e', CNTRL_ONLY, "PushCurChoice()", 0, CMDID_PUSHCURCHOICE },
    { 'f', CNTRL_ONLY, "Front()", 0, CMDID_FRONT },
@@ -57,9 +57,9 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { 's', CNTRL_ONLY, "Save()", 0, CMDID_SAVE },
    { 't', CNTRL_ONLY, "AlignToGrid()", 0, CMDID_ALIGNTOGRID },
    { 'u', CNTRL_ONLY, "UnGroup()", 0, CMDID_UNGROUP },
-   { 'v', CNTRL_ONLY, "Paste()", 0, CMDID_PASTE },
+   { 'v', CNTRL_ONLY, "PasteFromCutBuffer()", 0, CMDID_PASTE },
    { 'w', CNTRL_ONLY, "DrawText()", 0, CMDID_DRAWTEXT },
-   { 'x', CNTRL_ONLY, "Delete()", 0, CMDID_DELETE },
+   { '\0', 0, "Delete()", 0, CMDID_DELETE },
    { 'y', CNTRL_ONLY, "Redo()", 0, CMDID_REDO },
    { 'z', CNTRL_ONLY, "Undo()", 0, CMDID_UNDO },
    { ',', CNTRL_ONLY, "ScrollLeft()", 0, CMDID_SCROLLLEFT },
@@ -353,6 +353,7 @@ static struct ShortCutRec shortCutXlateTbl[] = {
                CMDID_SETALTEDITTEXTHIGHLIGHTCOLOR },
    { '\0', 0, "ToggleAltEditTextBgColor()", 0, CMDID_TOGGLEALTEDITTEXTBGCOLOR },
    { '\0', 0, "ChangeAllSelFontUnderline()",0,CMDID_CHANGEALLSELFONTUNDERLINE },
+   { '\0', 0, "ChangeAllSelFontOverline()",0,CMDID_CHANGEALLSELFONTOVERLINE },
    { '\0', 0, "EditPageFileNames()", 0, CMDID_EDITPAGEFILENAMES },
    { '\0', 0, "ExportHalfToneBitmap()", 0, CMDID_EXPORTHALFTONEBITMAP },
    { '\0', 0, "ExportThresholdBitmap()", 0, CMDID_EXPORTTHRESHOLDBITMAP },
@@ -433,6 +434,40 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { '\0', 0, "SetObjectShadowOffsets()", 0, CMDID_SETOBJSHADOWOFFSETS },
    { '\0', 0, "AddObjectShadow()", 0, CMDID_ADDOBJSHADOW },
    { '\0', 0, "RemoveObjectShadow()", 0, CMDID_REMOVEOBJSHADOW },
+   { '\0', 0, "CopyDoubleByteString()", 0, CMDID_COPYUTF8 },
+   { '\0', 0, "PasteDoubleByteString()", 0, CMDID_PASTEUTF8 },
+   { '\0', 0, "ReduceToMobileWebSafeColors()", 0,
+               CMDID_REDUCETOMOBILEWEBCOLORS },
+   { '\0', 0, "CreatePixmapFromSelected()", 0, CMDID_CREATEPIXMAPFROMSEL },
+   { '\0', 0, "ToggleAutoRotatePivot()", 0, CMDID_TOGGLEROTATEPIVOT },
+   { '\0', 0, "SpecifyRotatePivot()", 0, CMDID_SPECIFYROTATEPIVOT },
+   { '\0', 0, "ResetRotatePivot()", 0, CMDID_RESETROTATEPIVOT },
+   { '\0', 0, "NextPolyRotationPivot()", 0, CMDID_NEXTPOLYROTATEPIVOT },
+   { '\0', 0, "MoveRotationPivotToArcCenter()", 0,
+               CMDID_MOVEROTATEPIVOTARCCNTR },
+   { '\0', 0, "MoveRotatePivotCenter()", 0, CMDID_MOVEROTATEPIVOTCENTER },
+   { '\0', 0, "MoveRotatePivotLeftTop()", 0, CMDID_MOVEROTATEPIVOTLT },
+   { '\0', 0, "MoveRotatePivotRightTop()", 0, CMDID_MOVEROTATEPIVOTRT },
+   { '\0', 0, "MoveRotatePivotLeftBottom()", 0, CMDID_MOVEROTATEPIVOTLB },
+   { '\0', 0, "MoveRotatePivotRightBottom()", 0, CMDID_MOVEROTATEPIVOTRB },
+   { '\0', 0, "MoveRotatePivotLeft()", 0, CMDID_MOVEROTATEPIVOTLEFT },
+   { '\0', 0, "MoveRotatePivotRight()", 0, CMDID_MOVEROTATEPIVOTRIGHT },
+   { '\0', 0, "MoveRotatePivotTop()", 0, CMDID_MOVEROTATEPIVOTTOP },
+   { '\0', 0, "MoveRotatePivotBottom()", 0, CMDID_MOVEROTATEPIVOTBOTTOM },
+   { '\0', 0, "ChooseRotatePivot()", 0, CMDID_CHOOSEROTATEPIVOT },
+   { '\0', 0, "ChooseColor()", 0, CMDID_COLORWHEEL },
+   { '\0', 0, "ExtendSegment()", 0, CMDID_EXTENDSEGMENT },
+   { '\0', 0, "InsertSymbol()", 0, CMDID_INSERTSYMBOL },
+   { '\0', 0, "ToggleRightMargin()", 0, CMDID_TOGGLERIGHTMARGIN },
+   { '\0', 0, "SpecifyRightMargin()", 0, CMDID_SPECIFYRIGHTMARGIN },
+   { '\0', 0, "ToggleTighterStructuredSplines()", 0,
+               CMDID_TOGGLETIGHTERSPLINES },
+   { '\0', 0, "ToggleFloodReplaceColorThreshold()", 0,
+               CMDID_TOGGLEFLOODREPLACECOLORTHRESH },
+   { '\0', 0, "SetFloodReplaceColorThreshold()", 0,
+               CMDID_SETFLOODREPLACECOLORTHRESH },
+   { '\0', 0, "RemoveTransparentPixel()", 0, CMDID_REMOVETRANSPIXEL },
+   { '\0', 0, "ReplaceColorWithTrans()", 0, CMDID_REPLACECOLORWITHTRANS },
    { '\0', 0, "", 0, 0 }
 };
 
@@ -558,18 +593,16 @@ void InitShortCut()
                            if (*buf>='a' && *buf<='z') {
                               code = *buf-'a'+'A';
                               if (shortCutIndex[code] != INVALID) {
-                                 fprintf(stderr,
-                                       TgLoadString(STID_DUP_SHORTCUT_ENTRY_FOR_CHAR),
-                                       code);
+                                 fprintf(stderr, TgLoadString(
+                                       STID_DUP_SHORTCUT_ENTRY_FOR_CHAR), code);
                                  fprintf(stderr, "\n");
                               }
                               shortCutIndex[code] = j;
                            } else if (*buf>='A' && *buf<='Z') {
                               code = *buf-'A'+'a';
                               if (shortCutIndex[code] != INVALID) {
-                                 fprintf(stderr,
-                                       TgLoadString(STID_DUP_SHORTCUT_ENTRY_FOR_CHAR),
-                                       code);
+                                 fprintf(stderr, TgLoadString(
+                                       STID_DUP_SHORTCUT_ENTRY_FOR_CHAR), code);
                                  fprintf(stderr, "\n");
                               }
                               shortCutIndex[code] = j;
@@ -580,59 +613,60 @@ void InitShortCut()
                      }
                   }
                   if (*(shortCutXlateTbl[j].name) == '\0') {
-#ifdef _TANGRAM_II
-                     int num_args=0;
-                     int index=ValidTangram2CmdName(&buf[2], len, &num_args);
+                     if (cmdLineTgrm2) {
+                        int num_args=0;
+                        int index=ValidTangram2CmdName(&buf[2], len, &num_args);
 
-                     if (index != 0) {
-                        if (num_args != 0) {
-                           shortCutArgs[code] = (char*)malloc(
-                                 (strlen(&buf[len+2])+1)*sizeof(char));
-                           if (shortCutArgs[code] == NULL) FailAllocMessage();
-                           strcpy(shortCutArgs[code], ++paren_ptr);
-                        }
-                        if (shortCutIndex[code] != INVALID) {
-                           fprintf(stderr,
-                                 TgLoadString(STID_DUP_SHORTCUT_ENTRY_FOR_CHAR),
-                                 code);
-                           fprintf(stderr, "\n");
-                        }
-                        shortCutIndex[code] = index;
-                        if (!precise_match) {
-                           if (*buf>='a' && *buf<='z') {
-                              code = *buf-'a'+'A';
-                              if (shortCutIndex[code] != INVALID) {
-                                 fprintf(stderr,
-                                       TgLoadString(STID_DUP_SHORTCUT_ENTRY_FOR_CHAR),
-                                       code);
-                                 fprintf(stderr, "\n");
+                        if (index != 0) {
+                           if (num_args != 0) {
+                              shortCutArgs[code] = (char*)malloc(
+                                    (strlen(&buf[len+2])+1)*sizeof(char));
+                              if (shortCutArgs[code] == NULL) {
+                                 FailAllocMessage();
                               }
-                              shortCutIndex[code] = index;
-                           } else if (*buf>='A' && *buf<='Z') {
-                              code = *buf-'A'+'a';
-                              if (shortCutIndex[code] != INVALID) {
-                                 fprintf(stderr,
-                                       TgLoadString(STID_DUP_SHORTCUT_ENTRY_FOR_CHAR),
-                                       code);
-                                 fprintf(stderr, "\n");
-                              }
-                              shortCutIndex[code] = index;
+                              strcpy(shortCutArgs[code], ++paren_ptr);
                            }
+                           if (shortCutIndex[code] != INVALID) {
+                              fprintf(stderr, TgLoadString(
+                                    STID_DUP_SHORTCUT_ENTRY_FOR_CHAR), code);
+                              fprintf(stderr, "\n");
+                           }
+                           shortCutIndex[code] = index;
+                           if (!precise_match) {
+                              if (*buf>='a' && *buf<='z') {
+                                 code = *buf-'a'+'A';
+                                 if (shortCutIndex[code] != INVALID) {
+                                    fprintf(stderr, TgLoadString(
+                                          STID_DUP_SHORTCUT_ENTRY_FOR_CHAR),
+                                          code);
+                                    fprintf(stderr, "\n");
+                                 }
+                                 shortCutIndex[code] = index;
+                              } else if (*buf>='A' && *buf<='Z') {
+                                 code = *buf-'A'+'a';
+                                 if (shortCutIndex[code] != INVALID) {
+                                    fprintf(stderr, TgLoadString(
+                                          STID_DUP_SHORTCUT_ENTRY_FOR_CHAR),
+                                          code);
+                                    fprintf(stderr, "\n");
+                                 }
+                                 shortCutIndex[code] = index;
+                              }
+                           }
+                           maxShortCuts++;
+                        } else {
+                           found = FALSE;
                         }
-                        maxShortCuts++;
                      } else {
                         found = FALSE;
                      }
-#else /* ~_TANGRAM_II */
-                     found = FALSE;
-#endif /* _TANGRAM_II */
                   }
                   if (!found) {
                      fprintf(stderr,
                            TgLoadString(STID_INVALID_SHORTCUT_ENTRY_SKIP), buf);
                      fprintf(stderr, "\n");
                   }
-               } else if (FunctionKeySpec(buf, &code, &func_index)) {
+               } else if (FunctionKeySpec(buf, (int*)&code, &func_index)) {
                   int found=FALSE;
                   char *paren_ptr=NULL;
    
@@ -738,8 +772,7 @@ int FetchShortCut(c, code, state, name, args, args_sz)
 {
    if (shortCutIndex[c] == INVALID) return FALSE;
 
-#ifdef _TANGRAM_II
-   if ((shortCutIndex[c] & CMDID_TANGRAM2_BASE) != 0) {
+   if (cmdLineTgrm2 && (shortCutIndex[c] & CMDID_TANGRAM2_BASE) != 0) {
       /* for tangram-II, just do it */
       int num_args=0;
 
@@ -753,7 +786,6 @@ int FetchShortCut(c, code, state, name, args, args_sz)
 
       return FALSE;
    }
-#endif /* _TANGRAM_II */
    *code = shortCutXlateTbl[shortCutIndex[c]].code;
    *state = shortCutXlateTbl[shortCutIndex[c]].state;
    *name = shortCutXlateTbl[shortCutIndex[c]].name;
