@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2009, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2011, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shortcut.c,v 1.36 2009/10/22 00:00:17 cvsps Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shortcut.c,v 1.46 2011/05/16 16:21:59 william Exp $
  */
 
 #define _INCLUDE_FROM_SHORTCUT_C_
@@ -54,7 +54,7 @@ static struct ShortCutRec shortCutXlateTbl[] = {
 /* Control Keys */
    { 'a', CNTRL_ONLY, "SelectAll()", 0, CMDID_SELECTALL },
    { 'b', CNTRL_ONLY, "Back()", 0, CMDID_BACK },
-   { 'c', CNTRL_ONLY, "Copy()", 0, CMDID_COPY },
+   { 'c', CNTRL_ONLY, "CopyToCutBuffer()", 0, CMDID_COPY },
    { 'd', CNTRL_ONLY, "Duplicate()", 0, CMDID_DUPLICATE },
    { 'e', CNTRL_ONLY, "PushCurChoice()", 0, CMDID_PUSHCURCHOICE },
    { 'f', CNTRL_ONLY, "Front()", 0, CMDID_FRONT },
@@ -70,9 +70,9 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { 's', CNTRL_ONLY, "Save()", 0, CMDID_SAVE },
    { 't', CNTRL_ONLY, "AlignToGrid()", 0, CMDID_ALIGNTOGRID },
    { 'u', CNTRL_ONLY, "UnGroup()", 0, CMDID_UNGROUP },
-   { 'v', CNTRL_ONLY, "Paste()", 0, CMDID_PASTE },
+   { 'v', CNTRL_ONLY, "PasteFromCutBuffer()", 0, CMDID_PASTE },
    { 'w', CNTRL_ONLY, "DrawText()", 0, CMDID_DRAWTEXT },
-   { 'x', CNTRL_ONLY, "Delete()", 0, CMDID_DELETE },
+   { '\0', 0, "Delete()", 0, CMDID_DELETE },
    { 'y', CNTRL_ONLY, "Redo()", 0, CMDID_REDO },
    { 'z', CNTRL_ONLY, "Undo()", 0, CMDID_UNDO },
    { ',', CNTRL_ONLY, "ScrollLeft()", 0, CMDID_SCROLLLEFT },
@@ -473,7 +473,14 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { '\0', 0, "InsertSymbol()", 0, CMDID_INSERTSYMBOL },
    { '\0', 0, "ToggleRightMargin()", 0, CMDID_TOGGLERIGHTMARGIN },
    { '\0', 0, "SpecifyRightMargin()", 0, CMDID_SPECIFYRIGHTMARGIN },
-   { '\0', 0, "ToggleTighterStructuredSplines()", 0, CMDID_TOGGLETIGHTERSPLINES },
+   { '\0', 0, "ToggleTighterStructuredSplines()", 0,
+               CMDID_TOGGLETIGHTERSPLINES },
+   { '\0', 0, "ToggleFloodReplaceColorThreshold()", 0,
+               CMDID_TOGGLEFLOODREPLACECOLORTHRESH },
+   { '\0', 0, "SetFloodReplaceColorThreshold()", 0,
+               CMDID_SETFLOODREPLACECOLORTHRESH },
+   { '\0', 0, "RemoveTransparentPixel()", 0, CMDID_REMOVETRANSPIXEL },
+   { '\0', 0, "ReplaceColorWithTrans()", 0, CMDID_REPLACECOLORWITHTRANS },
    { '\0', 0, "", 0, 0 }
 };
 
