@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2009, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2011, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgcwdl.c,v 1.19 2009/06/10 21:36:12 cvsps Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgcwdl.c,v 1.21 2011/05/16 16:22:00 william Exp $
  */
 
 #define _INCLUDE_FROM_TGCWDL_C_
@@ -2118,6 +2118,9 @@ int TdgtColorWheelDlgLoop(pti)
          }
       } else if (xev.type == Expose) {
          ExposeEventHandler(&xev, FALSE);
+      } else if (xev.type == ConfigureNotify &&
+            xev.xany.window==mainWindow) {
+         Reconfigure(FALSE);
       } else if (xev.type == KeyPress) {
          TidgetManagerHandleAllKeyPressEvent(&xev);
       } else if (IsTdgtNotifyEvent(pti, &xev, &tdgt_notify)) {
